==> sagemaker_studio-1.0.5.tar.gz: sagemaker_studio-1.0.5/src/sagemaker_studio/_test/unit/connections/test_connections.py <==
import unittest
from unittest.mock import Mock

from botocore.exceptions import ClientError

from sagemaker_studio import ClientConfig
from sagemaker_studio.connections import ConnectionService
from sagemaker_studio.connections.connection import Connection


class TestConnections(unittest.TestCase):
    def setUp(self):
        self.mock_datazone_api = Mock()
        self.mock_glue_api = Mock()
        self.mock_secrets_manager_api = Mock()
        self.connections = ConnectionService(
            project_id="test_project",
            domain_id="test_domain",
            datazone_api=self.mock_datazone_api,
            glue_api=self.mock_glue_api,
            secrets_manager_api=self.mock_secrets_manager_api,
            project_config=ClientConfig(),
        )

    def test_get_connection_by_name_success(self):
        self.mock_datazone_api.list_connections.return_value = {
            "items": [{"connectionId": "12345", "name": "test_connection"}]
        }
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "12345",
            "secret": "my_secret",
            "name": "test_connection",
        }
        connection = self.connections.get_connection_by_name("test_connection")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project", name="test_connection"
        )
        self.mock_datazone_api.get_connection.assert_any_call(
            domainIdentifier="test_domain", identifier="12345", withSecret=True
        )

    def test_get_connection_by_name_no_connection_found(self):
        self.mock_datazone_api.list_connections.return_value = {"items": []}
        with self.assertRaises(AttributeError):
            self.connections.get_connection_by_name("nonexistent_connection")
        self.mock_datazone_api.list_connections.assert_called_once_with(
            domainIdentifier="test_domain",
            projectIdentifier="test_project",
            name="nonexistent_connection",
        )

    def test_list_connections_success(self):
        self.mock_datazone_api.list_connections.side_effect = [
            {"items": [{"name": "connection1", "type": "type1"}], "nextToken": "token1"},
            {"items": [{"name": "connection2", "type": "type2"}], "nextToken": None},
        ]
        self.mock_datazone_api.get_connection.return_value = {}
        connections = self.connections.list_connections()
        self.assertEqual(len(connections), 2)
        self.assertEqual(connections[0].name, "connection1")
        self.assertEqual(connections[1].name, "connection2")
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

    def test_list_connections_throw_client_error(self):
        self.mock_datazone_api.list_connections.side_effect = ClientError(
            error_response={"Error": {"Code": "AccessDeniedException"}},
            operation_name="ListConnections",
        )
        with self.assertRaises(RuntimeError) as context:
            self.connections.list_connections()
            self.assertTrue(
                "Encountered an error while listing connections for project" in context.exception
            )

        self.mock_datazone_api.list_connections.assert_called_once_with(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

    def test_list_connections_succeeds_when_get_connection_throws_client_error(self):
        self.mock_datazone_api.list_connections.side_effect = [
            {"items": [{"name": "connection1", "type": "type1"}], "nextToken": "token1"},
            {"items": [{"name": "connection2", "type": "type2"}], "nextToken": None},
        ]
        self.mock_datazone_api.get_connection.side_effect = ClientError(
            error_response={"Error": {"Code": "AccessDeniedException"}},
            operation_name="GetConnection",
        )

        connections = self.connections.list_connections()
        self.assertEqual(len(connections), 2)
        self.assertEqual(connections[0].name, "connection1")
        self.assertEqual(connections[1].name, "connection2")
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

==> sagemaker_studio-1.1.4.tar.gz: sagemaker_studio-1.1.4/src/sagemaker_studio/_test/unit/connections/test_connections.py <==
import unittest
from unittest.mock import Mock

from botocore.exceptions import ClientError

from sagemaker_studio import ClientConfig
from sagemaker_studio.connections import ConnectionService
from sagemaker_studio.connections.connection import Connection


class TestConnections(unittest.TestCase):
    def setUp(self):
        self.mock_datazone_api = Mock()
        self.mock_glue_api = Mock()
        self.mock_secrets_manager_api = Mock()
        self.mock_kms_api = Mock()
        self.connections = ConnectionService(
            project_id="test_project",
            domain_id="test_domain",
            datazone_api=self.mock_datazone_api,
            glue_api=self.mock_glue_api,
            secrets_manager_api=self.mock_secrets_manager_api,
            kms_api=self.mock_kms_api,
            project_config=ClientConfig(),
        )

    def test_get_connection_by_name_success(self):
        self.mock_datazone_api.list_connections.return_value = {
            "items": [{"connectionId": "12345", "name": "test_connection"}]
        }
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "12345",
            "secret": "my_secret",
            "name": "test_connection",
        }
        connection = self.connections.get_connection_by_name("test_connection")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project", name="test_connection"
        )
        self.mock_datazone_api.get_connection.assert_any_call(
            domainIdentifier="test_domain", identifier="12345", withSecret=True
        )

    def test_get_connection_by_name_no_connection_found(self):
        self.mock_datazone_api.list_connections.return_value = {"items": []}
        with self.assertRaises(AttributeError):
            self.connections.get_connection_by_name("nonexistent_connection")
        self.mock_datazone_api.list_connections.assert_called_once_with(
            domainIdentifier="test_domain",
            projectIdentifier="test_project",
            name="nonexistent_connection",
        )

    def test_list_connections_success(self):
        self.mock_datazone_api.list_connections.side_effect = [
            {"items": [{"name": "connection1", "type": "type1"}], "nextToken": "token1"},
            {"items": [{"name": "connection2", "type": "type2"}], "nextToken": None},
        ]
        self.mock_datazone_api.get_connection.return_value = {}
        connections = self.connections.list_connections()
        self.assertEqual(len(connections), 2)
        self.assertEqual(connections[0].name, "connection1")
        self.assertEqual(connections[1].name, "connection2")
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

    def test_list_connections_throw_client_error(self):
        self.mock_datazone_api.list_connections.side_effect = ClientError(
            error_response={"Error": {"Code": "AccessDeniedException"}},
            operation_name="ListConnections",
        )
        with self.assertRaises(RuntimeError) as context:
            self.connections.list_connections()
            self.assertTrue(
                "Encountered an error while listing connections for project" in context.exception
            )

        self.mock_datazone_api.list_connections.assert_called_once_with(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

    def test_list_connections_succeeds_when_get_connection_throws_client_error(self):
        self.mock_datazone_api.list_connections.side_effect = [
            {"items": [{"name": "connection1", "type": "type1"}], "nextToken": "token1"},
            {"items": [{"name": "connection2", "type": "type2"}], "nextToken": None},
        ]
        self.mock_datazone_api.get_connection.side_effect = ClientError(
            error_response={"Error": {"Code": "AccessDeniedException"}},
            operation_name="GetConnection",
        )

        connections = self.connections.list_connections()
        self.assertEqual(len(connections), 2)
        self.assertEqual(connections[0].name, "connection1")
        self.assertEqual(connections[1].name, "connection2")
        self.mock_datazone_api.list_connections.assert_any_call(
            domainIdentifier="test_domain", projectIdentifier="test_project"
        )

    def test_get_connection_by_id_success(self):
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "12345",
            "secret": "my_secret",
            "name": "test_connection",
        }
        connection = self.connections.get_connection_by_id("12345")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.get_connection.assert_called_once_with(
            domainIdentifier="test_domain", identifier="12345", withSecret=True
        )

    def test_get_connection_by_id_client_error(self):
        self.mock_datazone_api.get_connection.side_effect = ClientError(
            error_response={"Error": {"Code": "ResourceNotFoundException"}},
            operation_name="GetConnection",
        )
        with self.assertRaises(ClientError):
            self.connections.get_connection_by_id("nonexistent_id")
        self.mock_datazone_api.get_connection.assert_called_once_with(
            domainIdentifier="test_domain", identifier="nonexistent_id", withSecret=True
        )

    def test_get_connection_by_type_spark_connect_with_default_connection(self):
        self.mock_datazone_api.list_connections.return_value = {
            "items": [
                {
                    "connectionId": "12345",
                    "secret": "my_secret",
                    "name": "test_connection",
                    "type": "SPARK_CONNECT",
                },
                {
                    "connectionId": "54321",
                    "secret": "my_secret2",
                    "name": "default.athena.spark",
                    "type": "SPARK_CONNECT",
                },
            ]
        }
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "54321",
            "secret": "my_secret2",
            "name": "serverless.spark",
            "type": "SPARK_CONNECT",
        }
        connection = self.connections.get_connection_by_type("SPARK_CONNECT")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.get_connection.assert_called_once_with(
            domainIdentifier="test_domain", identifier="54321", withSecret=True
        )

    def test_get_connection_by_type_spark_connect_without_default_connection(self):
        self.mock_datazone_api.list_connections.return_value = {
            "items": [
                {
                    "connectionId": "12345",
                    "secret": "my_secret",
                    "name": "test_connection",
                    "type": "SPARK_CONNECT",
                },
                {
                    "connectionId": "54321",
                    "secret": "my_secret2",
                    "name": "test_connection2",
                    "type": "SPARK_CONNECT",
                },
            ]
        }
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "12345",
            "secret": "my_secret",
            "name": "test_connection",
            "type": "SPARK_CONNECT",
        }
        connection = self.connections.get_connection_by_type("SPARK_CONNECT")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.get_connection.assert_called_once_with(
            domainIdentifier="test_domain", identifier="12345", withSecret=True
        )

    def test_get_connection_by_type_other_type(self):
        self.mock_datazone_api.list_connections.return_value = {
            "items": [
                {
                    "connectionId": "12345",
                    "secret": "my_secret",
                    "name": "test_connection",
                    "type": "ATHENA",
                },
                {
                    "connectionId": "54321",
                    "secret": "my_secret2",
                    "name": "default.athena.spark",
                    "type": "ATHENA",
                },
            ]
        }
        self.mock_datazone_api.get_connection.return_value = {
            "connectionId": "12345",
            "secret": "my_secret",
            "name": "test_connection",
            "type": "ATHENA",
        }
        connection = self.connections.get_connection_by_type("ATHENA")
        self.assertIsInstance(connection, Connection)
        self.mock_datazone_api.get_connection.assert_called_once_with(
            domainIdentifier="test_domain", identifier="12345", withSecret=True
        )

    def test_get_connection_by_type_client_error(self):
        self.mock_datazone_api.list_connections.side_effect = ClientError(
            error_response={"Error": {"Code": "ResourceNotFoundException"}},
            operation_name="GetConnection",
        )
        with self.assertRaises(ClientError):
            self.connections.get_connection_by_type("test_type")
        self.mock_datazone_api.list_connections.assert_called_once_with(
            domainIdentifier="test_domain", projectIdentifier="test_project", type="test_type"
        )
